function [simulatedvalue,theoreticalvalue]= driftedBM
% Matlab simulation drifted BM X= 1+2t+2W_t
tic
%% parameter input
% horizon
T=1;
% sample size
Nplot=10;
Nsimu=10^5;
% grid points
M=10^3;
% volatility
sigma=2;
driftcoeff=2;

% theoretical value
theoreticalvalue= exp(1+driftcoeff*T+sigma^2/2*T);
%% Simulation
% BM
BM = [zeros(1,Nplot);sqrt(T/M)*cumsum(randn(M,Nplot))];
% the process X^(a)
timegrid= 0:T/M:T;
drift=repmat(timegrid',1,Nplot);
Xa=1+driftcoeff*drift+sigma*BM;

%plot the sample paths
plot(timegrid,Xa(:,:))

%compute simulated value
normalrv=sqrt(T)*randn(1,Nsimu);
simulatedvalue= mean(exp(1+driftcoeff*T+sigma*normalrv));

%estimated variance
estvar= var(exp(1+driftcoeff*T+sigma*normalrv));
% confidence interval using CLT
cfplus=simulatedvalue+1.96*sqrt(estvar/Nsimu);
cfminus=simulatedvalue-1.96*sqrt(estvar/Nsimu);

disp('Exact value:')
disp(theoreticalvalue)
disp('Estimated value: ')
disp(simulatedvalue)
disp('Confidence interval: ')
disp([cfminus,cfplus])
toc