function [zoptns,zoptsv,resns,ressv]=nelsonsiegel
% Given a finite number of bond prices we plot the calibrated forward curve
%using Nelson Siegel family/ Svensson family.

%% Input
%p= [n*1] bond price; n = number of bonds
% Table 3.2 first 3 bonds
%C= [n*N] CF matrix; N = number of cash flow dates (e.g., coupon payments)
%T= [N*1] payment tenor
p=[103.82;106.04;118.44];
C=zeros(length(p),1+3+6);
C(3,1)=6.125;
C(1,2)=105;
C(2,3)=4.875;
C(3,4)=6.125;
C(2,5)=4.875;
C(3,6)=6.125;
C(2,7)=104.875;
C(3,8)=6.125;
C(3,9)=6.125;
C(3,10)=106.125;

% number of days between today 04/09/96 and the next CF date
T=[22;72;137;203;318;387;502;568;752;933];
% day count convention= actual/365
T=T/365;

%% Optimization
% bond prices d(z) using Nelson-Siegel Ansatz
% z is four-dimensional
funns = @(z,C) C*(exp(-(z(1)*T+z(2)/z(4)*(1-exp(-z(4)*T))-z(3)/z(4)*T.*exp(-z(4)*T)+z(3)/(z(4)^2)*(1-exp(-z(4)*T)))));

% bond prices d(z) using Svensson Ansatz
% z is six-dimensional
funsv = @(z,C) C*(exp(-(z(1)*T+z(2)/z(5)*(1-exp(-z(5)*T))-z(3)/z(5)*T.*exp(-z(5)*T)+z(3)/(z(5)^2)*(1-exp(-z(5)*T))-z(4)/z(6)*T.*exp(-z(6)*T)+z(4)/(z(6)^2)*(1-exp(-z(6)*T)))));

% numerical search for the least squared problem
% min || C*d(z) - p|| over z

z0ns=0.05*ones(4,1);
z0sv=0.1*ones(6,1);
[zoptns,resns]= lsqcurvefit(@(z,C) funns(z,C),z0ns,C,p);
[zoptsv,ressv]= lsqcurvefit(@(z,C) funsv(z,C),z0sv,C,p);


% plot the forward curve
figure(1)
time = 0:0.01:T(end);
NSforward= zoptns(1)+(zoptns(2)+zoptns(3)*time).*exp(-zoptns(4)*time);
SVforward= zoptsv(1)+(zoptsv(2)+zoptsv(3)*time).*exp(-zoptsv(5)*time)+zoptsv(4)*time.*exp(-zoptsv(6)*time);
plot(time,NSforward,'r-',time,SVforward,'b-')
legend('Nelson-Siegel','Svensson')
xlabel('time')
ylabel('instantaneous forward rate')
title('calibrated forward curve -- today is 04/09/96')
end

