function [simulatedvalue,theoreticalvalue]= poissonprocess
% In this exercise we simulated 10 paths of Poisson process with
% itensity lambda=2
tic
%% parameter input
% horizon
T=1;
% sample size
Nplot=10;
Nsimu=10^5;
% grid points
M=10^3;
% intensity
lambda=2;

% theoretical value
theoreticalvalue= exp(lambda*(exp(1)-1));
%% Simulation
% method 1
figure(1)
% number of total jumps at T
NT= poissrnd(lambda*T,1,Nplot);
temp1= zeros(max(NT),Nplot);
for i =1:Nplot
    %condition on N_T, the jump times are ordered uniformlly distributed
    temp1(1:NT(i),i)= sort(T*rand(1,NT(i)));
    stairs([0;temp1(1:NT(i),i)],(0:NT(i))');
    hold on
end
hold off

% method 2
PP = [zeros(1,Nplot);cumsum(poissrnd(lambda*T/M,M,Nplot))];
% the process X^(c)
timegrid= 0:T/M:T;
Xc=PP;

figure(2)
%show the first 10 sample paths
plot(timegrid,Xc(:,:))


%compute simulated value
poissonrv=poissrnd(lambda*T,1,Nsimu);
simulatedvalue= mean(exp(poissonrv));

%estimated variance
estvar= var(exp(poissonrv));
% confidence interval using CLT
cfplus=simulatedvalue+1.96*sqrt(estvar/Nsimu);
cfminus=simulatedvalue-1.96*sqrt(estvar/Nsimu);

disp('Exact value:')
disp(theoreticalvalue)
disp('Estimated value: ')
disp(simulatedvalue)
disp('Confidence interval: ')
disp([cfminus,cfplus])
toc
